@@ -1,6 +1,10 @@
+from html import escape
 from locale import strxfrm
 from os import linesep
-from typing import Callable, Sequence, no_type_check
+from typing import Callable, Match, Sequence, Tuple, Union, no_type_check
+
+from pygments.formatters.html import HtmlFormatter
+from pygments.styles import get_all_styles, get_style_by_name
 
 from markdown import Markdown
 from markdown.extensions import Extension
@@ -18,12 +22,47 @@ from markdown.extensions.smarty import makeExtension as smarty
 from markdown.extensions.tables import makeExtension as tables
 from markdown.extensions.toc import makeExtension as toc
 from markdown.extensions.wikilinks import makeExtension as wikilinks
-from pygments.formatters.html import HtmlFormatter
-from pygments.styles import get_all_styles, get_style_by_name
+from markdown.inlinepatterns import InlineProcessor
 
 _CODEHL_CLASS = "codehilite"
 
 
+class _B4HtmlProcessor(InlineProcessor):
+    """
+    The builtin html processors store & restore `<...>`
+    But does not check if `<...>` is valid html
+
+    This processor tries to escape invalid html
+    """
+
+    PRIORITY = 91
+
+    def __init__(self) -> None:
+        super().__init__(pattern="<([^>]*)>")
+
+    @no_type_check
+    def handleMatch(
+        self, m: Match[str], data: str
+    ) -> Union[Tuple[str, int, int], Tuple[None, None, None]]:
+        maybe_html = m.group(1)
+        chars = {*maybe_html}
+
+        if maybe_html.endswith("/") or chars & {"<"} or chars & {"=", '"'}:
+            return None, None, None
+        else:
+            escaped = escape(data)
+            return escaped, m.start(0), m.end(0)
+
+
+class _UserExts(Extension):
+    def extendMarkdown(self, md: Markdown) -> None:
+        md.inlinePatterns.register(
+            _B4HtmlProcessor(),
+            name=_B4HtmlProcessor.__qualname__,
+            priority=_B4HtmlProcessor.PRIORITY,
+        )
+
+
 @no_type_check
 def _extensions(style: str) -> Sequence[Extension]:
     return (
@@ -41,6 +80,7 @@ def _extensions(style: str) -> Sequence[Extension]:
         tables(),
         toc(),
         wikilinks(),
+        _UserExts(),
     )
 
 
@@ -64,3 +104,4 @@ def render(style: str) -> Callable[[str], str]:
 
     return render
 
+
